Lua_MailItemInfoWindow = class("Lua_MailItemInfoWindow", Lua_Window);
function Lua_MailItemInfoWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_MailItemInfoWindow";
	self.skinName = "MailItemInfoWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
	self.showCloseText = true;
	self.closeTextPosY = -441
end

function Lua_MailItemInfoWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.dragContainer = Lua_DragContainer.new(self.content, 530, 220, Lua_AxisDefine.Vertical);
	self.dragContainer:setLocation(0, 168, 0);

	self.dragList = Lua_DragList.new(self.content, 488, 124, Lua_AxisDefine.Horizontal);
	self.dragList:setListCell(Lua_AttachItem, 124, 124, 1);
	self.dragList:setCellSpacing(10, 0);
	self.dragList:setLocation(0, -60, 0);

	self.sureBtn:addClickFuntion(self, self.onButtonClick);

	self:addLuaEvent("UPDATA_MAILITEM_ONE", self, self.updataInfo);
	self:addLuaEvent("UPDATA_MAILITEM_LIST", self, self.updataInfoList);
end

function Lua_MailItemInfoWindow:showWin(param)
	self:superCall("showWin", param);
	Lua_ProxyManager.getProxy("Lua_MailProxy"):sGetSingleMailInfo(param);
end

function Lua_MailItemInfoWindow:updataInfoList(itemList)
	for k,v in ipairs(itemList) do
		if v.mail_id == self.showData then
			self:updataInfo(v);
			break;
		end
	end
end

function Lua_MailItemInfoWindow:updataInfo(data)
	self.data = data;

	self.mailTitleTxt.text = data.title;

	local over_time = data.overtime_tick - os.time();
	local info = DataCenter.mailData:mailContent(data) .. "_" .. LanUtil.formateStr(128009, Mathf.Ceil(over_time / 86400));
	self.dragContainer:clearList();
	self.dragContainer:addSubContainer(Lua_MailItemInfoDes, info, true);
	self.dragContainer.canDrag = not self.dragContainer.isTheEnd;

	if data.has_attach == 0 then
		self.mailIcon:setAltas("mail_atlas", "ui_yj_icon_02");
		self.sureBtn:setLangValue(128010); -- 删除
		self.sureBtn:setStyle(3);
	else
		self.mailIcon:setAltas("mail_atlas", "ui_yj_icon_01");
		self.sureBtn:setLangValue(128011); -- 领取
		self.sureBtn:setStyle(1);
	end

	if data.item_list ~= nil then
		local arr = Array();
		for k,v in ipairs(data.item_list) do
			arr:add({item = v, canGet = data.has_attach});
		end
		local posX = arr:getSize() < 5 and (488 - arr:getSize() * 134 + 10) / 2 or 0;
		self.dragList.canDrag = arr:getSize() > 3;
		self.dragList:setArrayData(arr);
		self.dragList:setLocation(posX, -60, 0);
	end
end

function Lua_MailItemInfoWindow:onButtonClick(go)
	if self.data == nil then
		return;
	end
	if self.data.has_attach == 0 then
		DataCenter.mailData.isRemove = true;
		Lua_ProxyManager.getProxy("Lua_MailProxy"):sRemoveMailItem(self.data.mail_id);
		self:hide();
	else
		DataCenter.mailData.isDrawAll = false;
		Lua_ProxyManager.getProxy("Lua_MailProxy"):sReceiveMailItem(self.data.mail_id);
	end 
end

function Lua_MailItemInfoWindow:dispose()
	if self.dragContainer ~= nil then
		self.dragContainer:dispose();
		self.dragContainer = nil;
	end
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end





--------------------------------------------------





Lua_MailItemInfoDes = class("Lua_MailItemInfoDes", Lua_DragContainerItem);
function Lua_MailItemInfoDes:ctor(sub)
	self:superCall("ctor", sub);
end

function Lua_MailItemInfoDes:buildShowItem()
	self:superCall("buildShowItem");

	self.des = UICreate.createLabel(self.content, nil, 0, 0, 530, 0, 24);
	self.des.anchorValue = 1;
	self.des.pivotValue = 1;
	self.des.alignmentValue = 0;
	self.des.colorStr = Lua_ColorDefine.transColor("846651");
	self.des.verticalOverflowValue = 1;

	self.mailPeriodTxt = UICreate.createLabel(self.content, nil, 0, 0, 530, 0, 24);
	self.mailPeriodTxt.anchorValue = 1;
	self.mailPeriodTxt.pivotValue = 1;
	self.mailPeriodTxt.alignmentValue = 5;
	self.mailPeriodTxt.colorStr = Lua_ColorDefine.transColor("9C8472");
	self.mailPeriodTxt.verticalOverflowValue = 1;
end

function Lua_MailItemInfoDes:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	local arr = string.split(data, "_");
	self.des.text = arr[1];
	self.des:resetSize()

	self.mailPeriodTxt.text = arr[2];
	self.mailPeriodTxt:setLocation(0, -self.des.height);
	self.mailPeriodTxt:resetSize()
end

function Lua_MailItemInfoDes:getWidth()
	return 530;
end

function Lua_MailItemInfoDes:getHeight()
	return self.des.height + self.mailPeriodTxt.height * 2;
end

function Lua_MailItemInfoDes:dispose()
	if self.des ~= nil then
		self.des:dispose();
		self.des = nil;
	end
	if self.mailPeriodTxt ~= nil then
		self.mailPeriodTxt:dispose();
		self.mailPeriodTxt = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end





--------------------------------------------------





Lua_AttachItem = class("Lua_AttachItem", Lua_ListCell);
function Lua_AttachItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_AttachItem:buildShowItem()
	self:superCall("buildShowItem");

	self.ItemIcon = Lua_ItemIcon.new(self.content);
end

function Lua_AttachItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	if data.canGet == 1 then
		self.ItemIcon:setGray(false);
	elseif data.canGet == 0 then
		self.ItemIcon:setGray(true);
	end

	if self.tvo == nil then
		self.tvo = Lua_ToolVo.createToolVo(data.item.id);
	else
		self.tvo:setData(data.item.id);
	end
	self.tvo:fromServer(data.item);
	self.ItemIcon:setData(self.tvo);
end

function Lua_AttachItem:onPressClick()
	if self.data == nil then
		return;
	end
	DataCenter.packUtil:showItemInfo(self.ItemIcon.data);
end

function Lua_AttachItem:onMouseDownHandle()
	self.ItemIcon:setScale(0.95, 0.95);
end

function Lua_AttachItem:onMouseUpHandle()
	self.ItemIcon:setScale(1, 1);
end

function Lua_AttachItem:dispose()
	if self.ItemIcon ~= nil then
		self.ItemIcon:dispose();
		self.ItemIcon = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end